@@ -223,10 +223,10 @@ G - G-language Genome Analysis Environment core interface module
          $gb->{LOCUS}->{date}            -date of accession 
 
  HEADER  
-    $gb->{HEADER}  
+         $gb->{HEADER}  
 
  COMMENT  
-    $gb->{COMMENT}  
+         $gb->{COMMENT}  
 
  FEATURE  
          Each FEATURE is numbered(FEATURE1 .. FEATURE1172), and is a 
@@ -239,6 +239,7 @@ G - G-language Genome Analysis Environment core interface module
          $gb->{FEATURE$i}->{join}
          $gb->{FEATURE$i}->{note}  
          $gb->{FEATURE$i}->{type}        -CDS,gene,RNA,etc.
+         $gb->{FEATURE$i}->{feature}     -same as $i
 
          To analyze each FEATURE, write: 
 
@@ -246,27 +247,28 @@ G - G-language Genome Analysis Environment core interface module
                print $gb->{$feature}->{type}, "\n";
          }  
 
-         Each CDS is stored in a similar manner.
-         There are 
-         $gb->{CDS$i}->{start}
-         $gb->{CDS$i}->{end}
-         $gb->{CDS$i}->{direction}
-         $gb->{CDS$i}->{join}
-         $gb->{CDS$i}->{feature}         -number $n for $gb->{FEATURE$n}
-                                          where "CDS$i" = "FEATURE$n"
-
          In the same manner, to analyze all CDS, write:  
  
          foreach my $cds ($gb->cds()){
                print $gb->{$cds}->{gene}, "\n";
          }
 
+         Feature or gene information can also be accessed with CDS numbers:
+         $gb->{CDS$i}->{start}
+
+         or with locus_tags or gene names (for CDS, tRNA, and rRNA)
+         $gb->{thrL}->{start}
+         $gb->{b0001}->{start}
+
  BASE COUNT  
          $gb->{BASE_COUNT}  
 
  SEQ  
          $gb->{SEQ}              -sequence data following "ORIGIN" 
 
+         or
+ 
+         $gb->seq()
 
 =head1 Supported methods of G-language Genome Analysis Environment
 
@@ -278,7 +280,16 @@ G - G-language Genome Analysis Environment core interface module
 
          Creates a G instance.
          First option is the filename of the database. Default format is
-         the GenBank database.
+         the GenBank database. Database format is guessed from the extensions.
+         (eg. .gbk => GenBank, .fasta => FASTA, .embl => EMBL)
+
+         There are also several sample bacterial genomes included in the system.
+         $eco   = new G("ecoli"); # Escherichia coli K12 MG1655 - NC_000913
+         $bsub  = new G("bsub");  # Bacillus subtilis           - NC_000964
+         $mgen  = new G("mgen");  # Mycoplasma genitalium       - NC_000908
+         $cyano = new G("cyano"); # Synechococcus sp.           - NC_005070
+         $pyro  = new G("pyro");  # Pyrococcus furiosus         - NC_003413
+
          Second option specifies detailed actions.
 
            'no msg'                  suprresses all STDOUT messages printed 
@@ -384,6 +395,28 @@ G - G-language Genome Analysis Environment core interface module
 
 =cut
 
+=head2 $gb->find()
+
+   Name: $gb->find()   -   search through the genome data object with keywords
+
+   Description:
+         This method provides powerful means to search within the G-language genome
+         data object with keywords. Given a set of keywords, this method returns
+         the list of feature IDs corresponding to the search query. In G-language Shell,
+         search results are also directly printed out.
+
+         eg. @features = $gb->find('RNA', 'tyrosine');    # multiple keywords are allowed.
+
+         Keywords can be specific to each of the feature attributes:
+
+         eg. $gb->find(-type=>'CDS', -product=>'metabolism', 'subunit');
+
+         Regular expressions are allowed for keywords:
+
+         eg. $gb->find(-type=>'CDS', -EC_number=>'^2.7.');
+
+=cut
+
 =head2 $gb->getseq()
 
    Name: $gb->getseq()   -   get nucleotide sequence of the given positions (Perl coordinates)
@@ -394,6 +427,11 @@ G - G-language Genome Analysis Environment core interface module
 
          eg. $gb->getseq(1,3); # returns the 2nd, 3rd, and 4th nucleotides.
 
+   Options:
+       -circular   when the first position is larger than the second position,
+                   retrieves the sequece spanning across the end of the circular
+                   chromosome. (ex: $gb->getseq(4639670, 5, -circular))
+
 =cut
 
 =head2 $gb->get_gbkseq()
@@ -406,6 +444,11 @@ G - G-language Genome Analysis Environment core interface module
 
          eg. $gb->get_gbkseq(1,3); # returns the 1st, 2nd, and 3rd nucleotides.
 
+   Options:
+       -circular   when the first position is larger than the second position,
+                   retrieves the sequece spanning across the end of the circular
+                   chromosome. (ex: $gb->getseq(4639670, 5, -circular))
+
 =cut
 
 =head2 $gb->get_cdsseq()
@@ -603,6 +646,10 @@ G - G-language Genome Analysis Environment core interface module
          eg. $gb->before_startcodon('CDS1', 100); 
              # returns 100 bp sequence upstream of the start codon of 'CDS1'.
 
+   Options:
+         Second argument specifying the length of sequence to retrieve is
+         optional. (default: 100).
+
 =cut
 
 =head2 $gb->after_startcodon()
@@ -616,6 +663,10 @@ G - G-language Genome Analysis Environment core interface module
          eg. $gb->after_startcodon('CDS1', 100); 
              # returns 100 bp sequence downstream of the start codon of 'CDS1'.
 
+   Options:
+         Second argument specifying the length of sequence to retrieve is
+         optional. (default: 100).
+
 =cut
 
 =head2 $gb->before_stopcodon()
@@ -629,6 +680,10 @@ G - G-language Genome Analysis Environment core interface module
          eg. $gb->before_stopcodon('CDS1', 100); 
              # returns 100 bp sequence upstream of the stop codon of 'CDS1'.
 
+   Options:
+         Second argument specifying the length of sequence to retrieve is
+         optional. (default: 100).
+
 =cut
 
 =head2 $gb->after_stopcodon()
@@ -642,6 +697,10 @@ G - G-language Genome Analysis Environment core interface module
          eg. $gb->after_stopcodon('CDS1', 100); 
              # returns 100 bp sequence downstream of the stop codon of 'CDS1'.
 
+   Options:
+         Second argument specifying the length of sequence to retrieve is
+         optional. (default: 100).
+
 =cut
 
 =head2 $gb->get_exon()
