@@ -32,14 +32,11 @@
 package G::DB::Boranch;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
-use SelfLoader;
 
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
+our @ISA = qw(Exporter AutoLoader);
+our @EXPORT = qw(
 	     pass_send
 	     pass_get
 );
@@ -50,8 +47,6 @@ require Exporter;
 
 my %data;
 
-__DATA__
-
 #::::::::::::::::::::::::::::::
 #           Methods
 #::::::::::::::::::::::::::::::
@@ -70,6 +65,7 @@ sub pass_get{
 }
 
 1;
+
 __END__
 
 
