@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -218,7 +218,6 @@ sub read_features{
 	    
 	    if ($this->{"FEATURE$num"}->{"type"} eq "CDS"){
 		$cds ++;
-		$this->{"CDS$cds"}->{"on"} = 1;
 		$this->{"FEATURE$num"}->{"cds"} = $cds;
 	    }
 
@@ -232,11 +231,9 @@ sub read_features{
 	    if (/join/){
 		if (/complement\(join/){
 		    $this->{"FEATURE$num"}->{"direction"} = "complement";
-		    $this->{"CDS$cds"}->{"direction"} = "complement";
 		    s/complement//;
 		}else{
 		    $this->{"FEATURE$num"}->{"direction"} = "direct";
-		    $this->{"CDS$cds"}->{"direction"} = "direct";
 		}
 
 		my $line = $_;
@@ -263,16 +260,11 @@ sub read_features{
 		$tmpfth =~ s/c//g;
 		my @choparray = split(/\.\./, $tmpfth);
 		$this->{"FEATURE$num"}->{"start"} = shift @choparray;
-		$this->{"CDS$cds"}->{"start"} = $this->{"FEATURE$num"}->{"start"};
 		$this->{"FEATURE$num"}->{"end"} = pop @choparray;
-		$this->{"CDS$cds"}->{"end"} = $this->{"FEATURE$num"}->{"end"};
 		$this->{"FEATURE$num"}->{"join"} = $fth;
-		$this->{"CDS$cds"}->{"join"} = $fth;
-		$this->{"CDS$cds"}->{"feature"} = $num;
 
 		if ($line =~ /\:/){
 		    $this->{"FEATURE$num"}->{"partial"} = $line;
-		    $this->{"CDS$cds"}->{"partial"} = $line;
 		}
 	    }elsif (/\?/){
 		$this->{"FEATURE$num"}->{"type"} = "partial_$key";
@@ -282,22 +274,10 @@ sub read_features{
 		$this->{"FEATURE$num"}->{"direction"} = "complement";
 		$this->{"FEATURE$num"}->{"start"} = $1;
 		$this->{"FEATURE$num"}->{"end"} = $2;
-		if ($this->{"FEATURE$num"}->{"type"} eq "CDS"){
-		    $this->{"CDS$cds"}->{"direction"} = "complement";
-		    $this->{"CDS$cds"}->{"start"} = $1;
-		    $this->{"CDS$cds"}->{"end"} = $2;
-		    $this->{"CDS$cds"}->{"feature"} = $num;
-		}
 	    }elsif (/(\d+)\.\.(\d+)/){
 		$this->{"FEATURE$num"}->{"direction"} = "direct";
 		$this->{"FEATURE$num"}->{"start"} = $1;
 		$this->{"FEATURE$num"}->{"end"} = $2;
-		if ($this->{"FEATURE$num"}->{"type"} eq "CDS"){
-		    $this->{"CDS$cds"}->{"direction"} = "direct";
-		    $this->{"CDS$cds"}->{"start"} = $1;
-		    $this->{"CDS$cds"}->{"end"} = $2;
-		    $this->{"CDS$cds"}->{"feature"} = $num;
-		}
 	    }elsif (/\s+complement\((\d+)\)/){
 		$this->{"FEATURE$num"}->{"direction"} = "complement";
 		$this->{"FEATURE$num"}->{"start"} = $1;
@@ -403,7 +383,7 @@ G::IO::EmblI
 
 =head1 AUTHOR
 
-Kazuharu Gaou Arakawa, gaou@g-language.org
+Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =head1 SEE ALSO
 
