@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -149,9 +149,22 @@ sub make_gb {
 	    my $str = "/".$_."="."\"".$gb->{$feat}->{$_}."\"";
 	    $lng = length($str);
 	    if($lng >= 58 ){
-		for($i = 0;$i < $lng;$i += 58){
-		    my $pr = substr($str,$i,58);
-		    printf OUT "%-20.20s %-58.58s\n","$dummy",$pr;
+		if($str =~ /\s/){
+		    my $tmpline = "";
+		    foreach my $word (split(/ /, $str)){
+			if(length($tmpline) + length($word) < 58){
+			    $tmpline .= $word . ' ';
+			}else{
+			    printf OUT "%-20.20s %-58.58s\n",$dummy,$tmpline;
+			    $tmpline = $word . ' ';
+			}
+		    }
+		    printf OUT "%-20.20s %-58.58s\n",$dummy,$tmpline;
+		}else{
+		    for($i = 0;$i < $lng;$i += 58){
+			my $pr = substr($str,$i,58);
+			printf OUT "%-20.20s %-58.58s\n",$dummy,$pr;
+		    }
 		}
 	    }else{
 		printf OUT "%-20.20s %-58.58s\n","$dummy",$str;
@@ -204,7 +217,7 @@ G::IO::GenBankO
 
 =head1 AUTHOR
 
-Kazuharu Gaou Arakawa, gaou@g-language.org
+Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =head1 SEE ALSO
 
