@@ -143,9 +143,7 @@ sub msg_ask_interface{
 sub msg_send{
     my @msg = @_;
 
-    if ($data{"interface"} eq 'STDOUT'){
-	print STDOUT @msg;
-    }elsif ($data{"interface"} eq 'GUI'){
+    if ($data{"interface"} eq 'GUI'){
 	$data{"term"} .= join('',@msg);
 	$term->insert('','','',join('',@msg));
     }elsif ($data{"interface"} eq 'Wx'){
@@ -156,15 +154,15 @@ sub msg_send{
 	my $tmp = join('', @msg);
 	$data{"term"} .= $tmp;
 	&$term($tmp);
+    }else{
+	print STDOUT @msg;
     }
 }
 
 sub msg_error{
     my @msg = @_;
 
-    if ($data{"interface"} eq 'STDOUT'){
-	print STDERR @msg;
-    }elsif ($data{"interface"} eq 'GUI'){
+    if ($data{"interface"} eq 'GUI'){
 	$data{"system"} .= join('', @msg);
 	$console->insert('','','',join('', @msg));
     }elsif ($data{"interface"} eq 'Wx'){
@@ -175,6 +173,8 @@ sub msg_error{
 	my $tmp = join('', @msg);
 	$data{"system"} .= $tmp;
 	&$console($tmp);
+    }else{
+	print STDERR @msg;
     }
 }
 
