@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -92,32 +92,107 @@ sub clone {
     return $new;
 }
 
+
+
+sub find {
+    my $this = shift;
+
+    my @args = @_;
+    my (@keywords, %keyhash, @results);
+    my $i = 0;
+
+    while(defined $args[$i]){
+        if (substr($args[$i], 0, 1) eq '-' && substr($args[$i], 1, 1) !~ /[0-9]/){
+            $keyhash{substr($args[$i],1)} = $args[$i + 1];
+            $i += 2;
+        }else{
+	    push(@keywords, $args[$i]);
+            $i ++;
+        }
+    }
+
+    foreach my $feat ($this->feature()){
+	my $flag = 0;
+
+	foreach my $key (keys %keyhash){
+	    my $val = $keyhash{$key};
+
+	    unless($this->{$feat}->{$key} =~ /$val/){
+		$flag = 1;
+		last;
+	    }
+	}
+
+	next if ($flag);
+
+	foreach my $key (@keywords){
+	    unless(join('%%%___%%%', values(%{$this->{$feat}})) =~ /$key/){
+		$flag = 1;
+		last;
+	    }
+	}
+    
+	push(@results, $feat) unless($flag);
+    }
+
+    if(msg_ask_interface() eq 'Shell'){
+	foreach my $feat (@results){
+	    my $gene = $this->{$feat}->{gene} || $this->{$feat}->{locus_tag} || $feat;
+	    my $ec = $this->{$feat}->{EC_number};
+	    $ec =~ s/\s+/,/g;
+	    $ec = '(' . $ec . ')' if (length $ec);
+
+	    printf "     %s\t%s\t%s\t%s %s\n", $feat, $gene, $this->{$feat}->{type}, $this->{$feat}->{product}, $ec;
+	}
+    }
+
+    return @results;
+}
+
+
+
 sub getseq {
     my $this = shift;
     my $start = shift;
     my $end = shift;
+    my $option = shift;
 
-    my $seq = substr($this->{SEQ}, $start, $end-$start+1);
-    
-    return $seq;
+    if($start < $end){
+	return substr($this->{SEQ}, $start, $end-$start+1);
+    }else{
+	if($option =~ /circ/){
+	    return substr($this->{SEQ}, $start) . 
+		substr($this->{SEQ}, 0, $end + 1);
+	}else{
+	    my ($start2, $end2) = sort {$a <=> $b} ($start, $end);
+	    return substr($this->{SEQ}, $start, $end-$start+1);
+	}
+    }
 }
 
 sub get_gbkseq {
     my $this = shift;
     my $start = shift;
     my $end = shift;
+    my $option = shift;
 
-    my $seq = substr($this->{SEQ}, $start -1, $end-$start+1);
-
-    return $seq;
+    return getseq($this, $start - 1, $end - 1, $option);
 }
 
 sub get_cdsseq {
     my $this = shift;
     my $object = shift;
 
-    my $cdsseq = $this->get_gbkseq($this->{$object}->{start}, 
-				   $this->{$object}->{end});
+    my $cdsseq = '';
+
+    if($this->{$object}->{start} > $this->{$object}->{end}){
+	$cdsseq = substr($this->{SEQ}, $this->{$object}->{start} - 1) . 
+	    $this->get_gbkseq(1, $this->{$object}->{end});
+    }else{
+	$cdsseq = $this->get_gbkseq($this->{$object}->{start}, 
+				    $this->{$object}->{end});
+    }
+
     $cdsseq = &complement($cdsseq) 
 	if ($this->{$object}->{direction} eq 'complement');
 
@@ -127,7 +202,7 @@ sub get_cdsseq {
 sub before_startcodon {
     my $this = shift;
     my $object = shift;
-    my $length = shift;
+    my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
 	return 
@@ -145,7 +220,7 @@ sub before_startcodon {
 sub after_startcodon {
     my $this = shift;
     my $object = shift;
-    my $length = shift;
+    my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
 	return 
@@ -163,7 +238,7 @@ sub after_startcodon {
 sub before_stopcodon {
     my $this = shift;
     my $object = shift;
-    my $length = shift;
+    my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
 	return 
@@ -181,7 +256,7 @@ sub before_stopcodon {
 sub after_stopcodon {
     my $this = shift;
     my $object = shift;
-    my $length = shift;
+    my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
 	return 
@@ -437,10 +512,7 @@ sub next_feature{
 
     $feature = $this->{$feature}->{left} if ($feature =~ /^INTER/);
 
-    my $i = $feature;
-    $i =~ s/FEATURE//g;
-
-    $i = $this->{$feature}->{feature} if ($feature =~ /^CDS/);
+    my $i = $this->{$feature}->{feature};
     $i ++;
 
     while(defined(%{$this->{"FEATURE$i"}})){
@@ -463,10 +535,7 @@ sub previous_feature{
 
     $feature = $this->{$feature}->{right} if ($feature =~ /^INTER/);
 
-    my $i = $feature;
-    $i =~ s/FEATURE//g;
-
-    $i = $this->{$feature}->{feature} if ($feature =~ /^CDS/);
+    my $i = $this->{$feature}->{feature} if ($feature =~ /^CDS/);
     $i --;
 
     while(defined(%{$this->{"FEATURE$i"}})){
