@@ -32,6 +32,7 @@ use SubOpt;
 use G::Tools::Graph;
 use G::Messenger;
 use G::Seq::Util;
+use G::Seq::Primitive;
 
 use strict;
 
@@ -135,7 +136,7 @@ sub base_counter{
 		if($start-1+$i<length($gb->{SEQ})){
 		    $hash[$upstream-$i]{kazu}++;
 		    $nuc=$gb->getseq($start-1+$i-$PatLen,$start-1+$i);
-		    $cnuc=_complement($nuc);
+		    $cnuc=complement($nuc);
 		    $hash[$upstream-$i]{$cnuc}++;
 		    $hash[0]{pat}{$cnuc}++;
 		}
