@@ -53,7 +53,7 @@ use File::Basename;
 use File::ShareDir ':ALL';
 
 our @ISA = qw(G::Prelude G::IO::GenBankI G::IO::GenBankO);
-our $VERSION = '1.7.0';
+our $VERSION = '1.7.2';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -87,7 +87,6 @@ Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 my $outfile = '';
 my $loaded = 0;
 my $infile = '';
-my $sharedir = dist_dir('g-language');
 
 #::::::::::::::::::::::::::::::
 #    Let the code begin...
@@ -98,7 +97,7 @@ sub new {
     my $filename = shift;
 
     if(length($filename) < 1){
-	$filename = "$sharedir/genomes/ecoli.gbk";
+	$filename = dist_file('g-language', 'genomes/ecoli.gbk');
 	msg_error("WARNING: no genome file specified. Loading Escherichia coli K12 MG1655 genome as a sample.\n");
     }elsif(
 	   $filename eq 'ecoli' || 
@@ -107,7 +106,7 @@ sub new {
 	   $filename eq 'mgen' || 
 	   $filename eq 'cyano'
 	   ){
-	$filename = "$sharedir/genomes/$filename.gbk";
+	$filename = dist_file('g-language', "genomes/$filename.gbk");
     }
 
     my @options = @_;
@@ -244,6 +243,9 @@ sub new {
 	    $this = new G::Skyline("blessed");
 	    $tmp = new G::Skyline($filename, "no msg", $format, "no cache");
 	    $this->multi_locus($tmp);
+
+	    set_gene_aliases($this);
+
 	    $this->seq_info() unless($no_msg);
 	}else{
 	    if ($without_annotation){
@@ -260,6 +262,8 @@ sub new {
 	    }else{
 		$this->next_locus($no_msg);
 
+		set_gene_aliases($this);
+
 		if($force_cache || $no_cache == 0){
 		    sdb_save($this, sprintf("cache-%s-%s-%s", $basename, $stat[7], $stat[9]));
 		}
@@ -323,6 +327,26 @@ sub loaded_msg {
     &msg_error($print);
 }
 
+sub set_gene_aliases{
+    my $this = shift;
+
+    foreach my $feat ($this->feature()){
+	next unless ($this->{$feat}->{type} =~ /CDS|RNA/);
+	
+	if(length $this->{$feat}->{gene}){
+	    $this->{$this->{$feat}->{gene}} = $this->{$feat};
+	}
+	
+	if(length $this->{$feat}->{locus_tag}){
+	    $this->{$this->{$feat}->{locus_tag}} = $this->{$feat};
+	}
+	
+	if($this->{$feat}->{type} eq 'CDS'){
+	    $this->{'CDS' . $this->{$feat}->{cds}} = $this->{$feat};
+	}
+    }
+}
+
 sub interpret_format {
     my $filename = shift;
 
@@ -404,7 +428,6 @@ sub multi_locus{
 
     do{
         my $F = 1;
-        my $C = 1;
         $lng = length($this->{"SEQ"});
         $this->{"LOCUS$i"} = $gb->{"LOCUS"};
         $this->{"HEADER$i"} = $gb->{"HEADER"};
@@ -415,17 +438,11 @@ sub multi_locus{
             $this->{"FEATURE$f"}->{"start"} = $gb->{"FEATURE$F"}->{"start"} + $lng;
             $this->{"FEATURE$f"}->{"end"}   = $gb->{"FEATURE$F"}->{"end"} + $lng;
             $this->{"FEATURE$f"}->{"locus"} = $i;
+	    $this->{"FEATURE$f"}->{"feature"} = $f;
 
 	    if($gb->{"FEATURE$F"}->{"type"} eq "CDS"){
-                $this->{"CDS$c"}              = $gb->{"CDS$C"};
-                $this->{"CDS$c"}->{"start"}   = $gb->{"CDS$C"}->{"start"} + $lng;
-                $this->{"CDS$c"}->{"end"}     = $gb->{"CDS$C"}->{"end"} + $lng;
-                $this->{"CDS$c"}->{"feature"} = $f;
-                $this->{"CDS$c"}->{"locus"}   = $i;
-
-
-                if(defined $gb->{"CDS$C"}->{"join"}){
-                    my @join = split(/\,/,$gb->{"CDS$C"}->{"join"});
+                if(defined $gb->{"FEATURE$F"}->{"join"}){
+                    my @join = split(/\,/,$gb->{"FEATURE$F"}->{"join"});
 		    my @num = ();
 		    my @new_join = ();
 
@@ -438,11 +455,10 @@ sub multi_locus{
                             push (@new_join, sprintf ("%d\.\.%d",  $num[0] + $lng, $num[1] + $lng));
                         }
                     }
-                    $this->{"CDS$c"}->{join} = join(',', @new_join);
+                    $this->{"FEATURE$f"}->{join} = join(',', @new_join);
                 }
 		$this->{"FEATURE$f"}->{"cds"} = $c;
                 $c++;
-                $C++;
             }
             $f++;
             $F++;
